@@ -22,7 +22,7 @@ class LoggedTask(Task):
         Emit a log statement when the task is submitted.
         """
         result = super().apply_async(args=args, kwargs=kwargs, **options)
-        log.info('Task {}[{}] submitted with arguments {}, {}'.format(
+        log.info('Task {}[{}] submitted with arguments {}, {}'.format(  # pylint: disable=consider-using-f-string
             self.name,
             result.id,
             args,
@@ -35,11 +35,19 @@ class LoggedTask(Task):
         Capture the exception that caused the task to be retried, if any.
         """
         super().on_retry(exc, task_id, args, kwargs, einfo)
-        log.warning('[{}] retried due to {}'.format(task_id, getattr(einfo, 'traceback', None)))
+        log.warning(
+            '[{}] retried due to {}'.format(  # pylint: disable=consider-using-f-string
+                task_id, getattr(einfo, 'traceback', None)
+            )
+        )
 
     def on_failure(self, exc, task_id, args, kwargs, einfo):
         """
         Capture the exception that caused the task to fail, if any.
         """
-        log.error('[{}] failed due to {}'.format(task_id, getattr(einfo, 'traceback', None)))
+        log.error(
+            '[{}] failed due to {}'.format(  # pylint: disable=consider-using-f-string
+                task_id, getattr(einfo, 'traceback', None)
+            )
+        )
         super().on_failure(exc, task_id, args, kwargs, einfo)
